@@ -19,5 +19,5 @@ from .notifications import (
     Webhook,
     get_default_notification_types,
 )
-from .owners import Owner, OwnerAsset
-from .structures import Structure, StructureService, StructureTag
+from .owners import Owner, OwnerAsset, OwnerCharacter
+from .structures import PocoDetails, Structure, StructureService, StructureTag
